#!/bin/sh
#
# Name: itEcfm
# Date: 2010-08-20 12:00
# Copyright: (C) 2010 Iskratel
# Author:  Goran trok <g.strok@iskratel.si>
# This software licensed to Iskratel Ltd.
#
#
### BEGIN INIT INFO
# Required-Start:
# Required-Stop:
# Should-Start:
# Should-Stop:
# Default-Start: 2 3 4 5
# Default-Stop: 0 1 6
# Short-Description: start/stop ECFM module.
# Description: Start and stop ECFM module.
# chkconfig: 2345 61 10
### END INIT INFO

# Init script information
INIT_NAME=itEcfm.sh
DESC="ECFM module"
DAEMON_NAME="itEcfm"
PACKAGE_PATH="/opt/si2000/neroot/active/"
WORKING_DIR=$PACKAGE_PATH"bin"
APPLICATION=$WORKING_DIR/$DAEMON_NAME
SIGUSR1=10
SIGUSR3=64
SIGTERM=15

# Following arguments are possible: debug|consolelog|nosyslog
ARGUMENTS=""

export ITECFMPIDFILE="/var/run/$DAEMON_NAME.pid"

STOP_WAITING_LIMIT=15  # in seconds

# Source the init script functions
. /etc/init.d/init-functions

export LD_LIBRARY_PATH="/opt/si2000/neroot/active/lib/"

start()
{
 local RET ERROR=
 PID=`pidof $APPLICATION`
 if [ "$PID" == "" ]
 then
  echo "Starting $DESC: $DAEMON_NAME... "

  $APPLICATION $ARGUMENTS &
  echo -n $!  > $ITECFMPIDFILE
 else
  echo "$DESC already started!"
  return 0
 fi
 sleep 1

 PID=`pidof $APPLICATION`
 if [ "$PID" == "" ]
 then
  echo "Can not start $DESC !!!!"
  rm $ITECFMPIDFILE
 else
  echo "done ..."
 fi
 return 0
}

stop () {
 local RET ERROR=
 local cnt=0
 local sleepPeriod=2
 local max=`expr $STOP_WAITING_LIMIT / $sleepPeriod`

 PID=`pidof $APPLICATION`
 if [ "$PID" == "" ]
 then
  echo "$DESC not started"
  return 0
 fi

 echo "Stopping $DESC: $DAEMON_NAME... "
 kill "-$SIGTERM" "$PID"
 RET=$?
 if [ $RET -eq 0 ]; then
  echo " done. "
 else
  echo "failed ($RET: Unable to stop $DAEMON_NAME). "
 fi
 return 0
}

restart() {
 local RET

 echo "Restarting $DESC..."
 stop
 start
 RET=$?

 return $RET
}

tryrestart() {
 local RET

 PID=`pidof $APPLICATION`
 RET=$?
 if [ "$RET" == "" ]; then
  restart
  RET=$?
 else
  RET=7
 fi

 return $RET
}

#
# if the service does not support reload return code 3 should
# be the result...
#
reload() {
 local RET
 PID=`pidof $APPLICATION`
 if [ "$PID" == "" ]
 then
  echo "$DESC not started"
  return 3
 fi
 echo "Reloading $DESC: $DAEMON_NAME... "
 kill "-$SIGUSR1" "$PID"
 RET=$?
 return $RET
}

forcereload() {
 local RET

 reload
 RET=$?
 if [ $RET -ne 0 ]; then
  restart
  RET=$?
 fi

 return $RET
}

status() {
 PID=`pidof $APPLICATION`
 if [ "$PID" == "" ]
 then
  echo "$DESC not running! "
 else
  echo "$DESC is running (PID = $PID)!"
 fi
 return 0
}

#
# In case when Http server present then Http ping over port 80 for ECFM must be impelemented by calling this script
#
ping() {
 local RET
 PID=`pidof $APPLICATION`
 if [ "$PID" == "" ]
 then
  echo "$DESC not started, Http ping not possible"
  return 3
 fi
 echo "Http request for $DESC: $DAEMON_NAME... "
 kill "-$SIGUSR3" "$PID"
 RET=$?
 return $RET
}

#
# Everything after this should be the same for all init scripts
#
# See the policy manual for information on actions and return codes.
#

parse() {
 case "$1" in
  start)
   start
   return $?
     ;;
  stop)
   stop
   return $?
   ;;
  restart)
   restart
   return $?
   ;;
  try-restart)
   tryrestart
   return $?
   ;;
   reload)
   reload
   return $?
   ;;
  force-reload)
   forcereload
   return $?
   ;;
  status)
   status
   return $?
   ;;
   *)
   echo "Usage: $INIT_NAME " \
   "{start | stop | restart | try-restart | reload | "\
   "force-reload | status }" >&2
   ;;
 esac

 return 1
}

parse $@
